def f1(a: e1, b: e2) -> r1:
    pass

def f2(a: e1, b: e2) -> r2:
    pass

def f3(a) -> r3:
    pass

def f4(a: e4, b):
    pass

def f5(a: e5) -> r5:
    # type: (Any) -> Any
    pass
